@@ -1927,6 +1927,63 @@ user_set_password (AccountsUser          *auser,
         return TRUE;
 }
 
+static void
+user_change_password_hint_authorized_cb (Daemon                *daemon,
+                                         User                  *user,
+                                         GDBusMethodInvocation *context,
+                                         gpointer               data)
+{
+        gchar *hint = data;
+
+        sys_log (context,
+                 "set password hint of user '%s' (%d)'",
+                 user->user_name, user->uid);
+
+        if (g_strcmp0 (user->password_hint, hint) != 0) {
+                g_free (user->password_hint);
+                user->password_hint = g_strdup (hint);
+
+                save_extra_data (user);
+
+                accounts_user_emit_changed (ACCOUNTS_USER (user));
+
+                g_object_notify (G_OBJECT (user), "password-hint");
+        }
+
+        accounts_user_complete_set_password_hint (ACCOUNTS_USER (user), context);
+}
+
+static gboolean
+user_set_password_hint (AccountsUser          *auser,
+                        GDBusMethodInvocation *context,
+                        const gchar           *hint)
+{
+        User *user = (User*)auser;
+        int uid;
+        const gchar *action_id;
+
+        if (!get_caller_uid (context, &uid)) {
+                throw_error (context, ERROR_FAILED, "identifying caller failed");
+                return FALSE;
+        }
+
+        if (user->uid == (uid_t) uid)
+                action_id = "org.freedesktop.accounts.change-own-user-data";
+        else
+                action_id = "org.freedesktop.accounts.user-administration";
+
+        daemon_local_check_auth (user->daemon,
+                                 user,
+                                 action_id,
+                                 TRUE,
+                                 user_change_password_hint_authorized_cb,
+                                 context,
+                                 g_strdup (hint),
+                                 (GDestroyNotify)g_free);
+
+        return TRUE;
+}
+
 static void
 user_change_automatic_login_authorized_cb (Daemon                *daemon,
                                            User                  *user,
@@ -2271,6 +2328,7 @@ user_accounts_user_iface_init (AccountsUserIface *iface)
         iface->handle_set_locked = user_set_locked;
         iface->handle_set_password = user_set_password;
         iface->handle_set_password_mode = user_set_password_mode;
+        iface->handle_set_password_hint = user_set_password_hint;
         iface->handle_set_real_name = user_set_real_name;
         iface->handle_set_shell = user_set_shell;
         iface->handle_set_user_name = user_set_user_name;
